@@ -59,23 +59,31 @@ void ChooseListToEdit(void)
   SDL_Surface *max_title_size = NULL; //using this to figure out size of wordlist name
 
   //Temporary holders and ptrs used while scanning list directory:
+  char wordsDir[FNLEN];
   char fn[FNLEN];                             
   FILE* fp = NULL;
   DIR* lists_dir = NULL;
   struct dirent* list_dirent = NULL;
 
-  DEBUGCODE { fprintf(stderr , "%s/words", settings.var_data_path); }
-
-
   /* First part - scan through our word list directory and create lists */
   /* of the filenames and titles (first lines in files).                */
   /* NOTE we could use scandir() to do almost all of this as we do      */
   /* in tuxmath.                                                        */
 
 
-  //Try to open directory for modifiable word lists:
-  sprintf(fn , "%s/words" , settings.var_data_path);
-  lists_dir = opendir(fn);
+  //Try to open a directory for modifiable word lists:
+
+  sprintf(wordsDir, "%s/words", settings.user_settings_path);
+  if (CheckFile(wordsDir))
+  {
+    DEBUGCODE { fprintf(stderr, "User specific wordlist path found: %s\n", wordsDir); }
+  }
+  else
+  {
+    DEBUGCODE { fprintf(stderr , "Editor: checking directory: %s/words", settings.var_data_path); }
+    sprintf(wordsDir , "%s/words" , settings.var_data_path);
+  }
+  lists_dir = opendir(wordsDir);
 
   if (!lists_dir)
   {
@@ -105,7 +113,7 @@ void ChooseListToEdit(void)
     if (strcmp(&list_dirent->d_name[strlen(list_dirent->d_name) -4 ],".txt"))
       continue;
 
-    snprintf(fn, FNLEN, "%s/words/%s" , settings.var_data_path, list_dirent->d_name); 
+    snprintf(fn, FNLEN, "%s/%s" , wordsDir, list_dirent->d_name); 
 
     /* CheckFile() returns 2 if dir, 1 if file, 0 if neither: */
     if (CheckFile(fn) == 1)
@@ -322,7 +330,7 @@ void ChooseListToEdit(void)
     {
       num_lists = 0;
       //Try to open directory for modifiable word lists:
-      sprintf(fn , "%s/words" , settings.var_data_path);
+      sprintf(fn , "%s" , wordsDir);
       lists_dir = opendir(fn);
 
       if (!lists_dir)
@@ -345,7 +353,7 @@ void ChooseListToEdit(void)
         if (strcmp("CVS", list_dirent->d_name) == 0)
           continue;
 
-        snprintf(fn, FNLEN, "%s/words/%s" , settings.var_data_path, list_dirent->d_name); 
+        snprintf(fn, FNLEN, "%s/%s" , wordsDir, list_dirent->d_name); 
 
         /* CheckFile() returns 2 if dir, 1 if file, 0 if neither: */
         if (CheckFile(fn) == 1)
@@ -493,14 +501,28 @@ void EditWordList(char* words_file)
   int i, len, j = 0; 
   int listening_for_new_word = 0;
   char fn[FNLEN];
+  char wordsDir[FNLEN];
   char words_in_list[MAX_NUM_WORDS][MAX_WORD_SIZE + 1];
 
   wchar_t temp[MAX_WORD_SIZE + 1];
 
+  // get appropriate directory
+  sprintf(wordsDir, "%s/words", settings.user_settings_path);
+  if (CheckFile(wordsDir))
+  {
+    DEBUGCODE { fprintf(stderr, "User specific wordlist path found: %s\n", wordsDir); }
+  }
+  else
+  {
+    DEBUGCODE { fprintf(stderr , "Editor: checking directory: %s/words", settings.var_data_path); }
+    sprintf(wordsDir , "%s/words" , settings.var_data_path);
+  }
+
+
   //We should be able to use GenerateWordList() in place of this next block:
   //NOTE: Works originally, but upon returning to editorlist, the word selected
   // is not there, since all words in the wordlist are deleted
-  sprintf(fn , "%s/words/%s", settings.var_data_path,  words_file);
+  sprintf(fn , "%s/%s", wordsDir,  words_file);
   fp = fopen(fn,"r");
   number_of_words = 0;  
 
@@ -942,12 +964,26 @@ int CreateNewWordList(void)
   SDL_Rect Directions_rect;
   FILE* fp = NULL;
   char fn[FNLEN];
+  char wordsDir[FNLEN];
   char wordlist[MAX_WORD_SIZE + 1];
   wchar_t temp[MAX_WORD_SIZE + 1];
   wordlist[0] = 0;
 
   LOG("Enter CreateNewWordList()\n");
 
+  // get appropriate directory
+  sprintf(wordsDir, "%s/words", settings.user_settings_path);
+  if (CheckFile(wordsDir))
+  {
+    DEBUGCODE { fprintf(stderr, "User specific wordlist path found: %s\n", wordsDir); }
+  }
+  else
+  {
+    DEBUGCODE { fprintf(stderr , "Editor: checking directory: %s/words", settings.var_data_path); }
+    sprintf(wordsDir , "%s/words" , settings.var_data_path);
+  }
+
+
   //Creates a box thing, tells user to enter in name of list.  Click OK, or CANCEL
   //FIXME: Create a rect for user to enter stuff, and a pretty box to go around everything
 
@@ -1135,7 +1171,7 @@ int CreateNewWordList(void)
   /* Creating file, if possible */
   if (save == 1)
   {
-    sprintf(fn, "%s/words/%s.txt", settings.var_data_path, wordlist);
+    sprintf(fn, "%s/%s.txt", wordsDir, wordlist);
     DEBUGCODE{ fprintf(stderr, "File to be saved: %s\n", fn); }
 
     fp = fopen(fn, "w");
@@ -1268,9 +1304,21 @@ int ChooseRemoveList(char *name, char *filename)
 int RemoveList(char* words_file)
 {
   char fn[FNLEN];
+  char wordsDir[FNLEN];
   LOG("Enter RemoveList()\n");
+  // get appropriate directory
+  sprintf(wordsDir, "%s/words", settings.user_settings_path);
+  if (CheckFile(wordsDir))
+  {
+    DEBUGCODE { fprintf(stderr, "User specific wordlist path found: %s\n", wordsDir); }
+  }
+  else
+  {
+    DEBUGCODE { fprintf(stderr , "Editor: checking directory: %s/words", settings.var_data_path); }
+    sprintf(wordsDir , "%s/words" , settings.var_data_path);
+  }
 
-  sprintf(fn , "%s/words/%s" , settings.var_data_path, words_file);
+  sprintf(fn , "%s/%s" , wordsDir, words_file);
 
   DEBUGCODE{ fprintf(stderr, "Remove file %s\n", fn); }
 
