@@ -38,6 +38,9 @@ void GraphicsInit(void)
   const SDL_VideoInfo* video_info = SDL_GetVideoInfo();
   Uint32 surface_mode = 0;
 
+  DEBUGCODE
+  { fprintf(stderr, "Entering GraphicsInit()\n"); };
+
   //Set application's icon:
   seticon();
   //Set caption:
@@ -138,23 +141,63 @@ void LibInit(Uint32 lib_flags)
               SDL_GetError());
       settings.sys_sound = 0;
     }
+    else
+      LOG("SDL_InitSubSystem(SDL_INIT_AUDIO) succeeded\n");
   }
 
-
 // atexit(SDL_Quit); // fire and forget... 
 
   LOG( "-SDL Library init'd successfully\n" );
 
+  DEBUGCODE
+  { fprintf(stderr, "settings.sys_sound = %d\n", settings.sys_sound); }
+
   /* FIXME should read settings before we do this: */ 
-  if (settings.sys_sound)
+  if (settings.sys_sound) //can be turned off with "--nosound" runtime flag
   {
-    if (Mix_OpenAudio(22050, AUDIO_S16, 1, 2048) == -1)
+    int initted = 1;
+
+    /* For SDL_mixer 1.2.10 and later, we must call Mix_Init() before any */
+    /* other SDL_mixer functions. We can see what types of audio files    */
+    /* are supported at this time (ogg and mod are required):             */
+
+#ifdef HAVE_MIX_INIT
+    int flags = MIX_INIT_OGG | MIX_INIT_MP3 | MIX_INIT_MOD | MIX_INIT_FLAC;
+    initted = Mix_Init(flags);
+
+    /* Just give warnings if MP3 or FLAC not supported: */
+    if((initted & MIX_INIT_MP3) != MIX_INIT_MP3)
+      LOG("NOTE - MP3 playback not supported\n");
+    if((initted & MIX_INIT_FLAC) != MIX_INIT_FLAC)
+      LOG("NOTE - MP3 playback not supported\n");
+
+    /* We must have Ogg and Mod support to have sound: */
+    if((initted & (MIX_INIT_OGG | MIX_INIT_MOD)) != (MIX_INIT_OGG | MIX_INIT_MOD))
     {
-      fprintf( stderr, "Warning: couldn't set 22050 Hz 8-bit audio\n - Reasons: %s\n", SDL_GetError());
-      settings.sys_sound=0;
+      fprintf(stderr, "Mix_Init: Failed to init required ogg and mod support!\n");
+      fprintf(stderr, "Mix_Init: %s\n", Mix_GetError());
+      settings.sys_sound = 0;
+      initted = 0;
     }
     else
-      LOG("Mix_OpenAudio() successful\n");
+      LOG("Mix_Init() succeeded\n");
+#endif
+
+    DOUT(initted);
+
+    /* If Mix_Init() succeeded (or wasn't required), set audio parameters: */
+    if(initted)
+    {
+      LOG("About to call Mix_OpenAudio():\n");
+//    if (Mix_OpenAudio(22050, AUDIO_S16, 1, 2048) == -1)
+      if(Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, 1, 2048) == -1)
+      {
+        fprintf(stderr, "Warning: Mix_OpenAudio() failed\n - Reasons: %s\n", SDL_GetError());
+        settings.sys_sound = 0;
+      }
+      else
+        LOG("Mix_OpenAudio() successful\n");
+    }
   }
 
   LOG( "-about to init SDL text library (SDL_ttf or SDL_Pango\n" );
@@ -183,7 +226,9 @@ void LoadSettings(void)
   /* set the settings directory/file */
 
 #ifdef WIN32
-  snprintf(fn, FNLEN - 1, "userdata/settings.txt");
+  // MDTTEMP: commented out the next line and added the line after
+  // snprintf(fn, FNLEN - 1, "userdata/settings.txt");
+  snprintf( fn, FNLEN-1, "%s/TuxType/settings.txt", getenv("APPDATA"));
   LOG("WIN32 defined\n");
 #else
   snprintf(fn, FNLEN - 1, (const char*)"%s/.tuxtype/settings.txt", getenv("HOME"));
@@ -208,7 +253,7 @@ static int load_settings_filename(const char* fn)
 
   if (!fp)
   {
-    fprintf(stderr, "load_settings_filename(): no theme-specific settings found%s\n",fn);
+    fprintf(stderr, "load_settings_filename(): no theme-specific settings found: %s\n",fn);
     return -1;
   }
 	
@@ -248,20 +293,20 @@ static int load_settings_fp(FILE* fp)
 
     DEBUGCODE {fprintf(stderr, "%s = %s", setting, value );}
       //For now we are not reading or saving the language selection: 
-//    if (strncmp( setting, "lang", FNLEN ) == 0 )
-//    {
-//      DEBUGCODE {fprintf(stderr, "LoadSettings: Setting language to %s\n", value);}
-//      strncpy(settings.lang, value, FNLEN - 1);
-//      setting_found = 1;
-//      SetupPaths(value); /* Does this really belong here? */ 
-//    }
-//    else
-    if (strncmp( setting, "o_lives", FNLEN ) == 0 )
+      //MDTTEMP: uncommented the following 8 lines and joined the else to the if on line 259
+    if (strncmp( setting, "lang", FNLEN ) == 0 )
+    {
+      DEBUGCODE {fprintf(stderr, "LoadSettings: Setting language to %s\n", value);}
+      strncpy(settings.lang, value, FNLEN - 1);
+      setting_found = 1;
+      SetupPaths(value); /* Does this really belong here? */ 
+    }
+    else if (strncmp( setting, "o_lives", FNLEN ) == 0 )
     {
       DEBUGCODE {fprintf(stderr, "LoadSettings: Setting lives to %s\n", value);}
       settings.o_lives = atoi(value);
       setting_found = 1;
-   }
+    }
     else if (strncmp( setting, "mus_volume", FNLEN ) == 0 )
     {
       DEBUGCODE {fprintf(stderr, "LoadSettings: Setting music volume to %s\n", value);}
@@ -296,7 +341,6 @@ static int load_settings_fp(FILE* fp)
       DEBUGCODE {fprintf(stderr, "load_settings_fp(): Setting theme locale to %s\n", value);}
       strncpy(settings.theme_locale_name, value, FNLEN - 1);
       setting_found = 1;
-      fprintf(stderr, "load_settings_fp(): Setting theme locale to %s\n", value);
     }
     else
       DEBUGCODE {fprintf(stderr, "load_settings_fp(): unrecognized string: %s\n", value);}
@@ -325,14 +369,22 @@ void SaveSettings(void)
 	
 	/* set the settings directory/file */
 
-	#ifdef WIN32
-		_mkdir( "userdata" );  // just in case try to create save location
-		snprintf( fn, FNLEN-1, "userdata/settings.txt" );
-	#else
-		snprintf( fn, FNLEN-1, (const char*)"%s/.tuxtype", getenv("HOME") );
-		mkdir( fn, 0755 ); // just in case try to create save location
-		snprintf( fn, FNLEN-1, (const char*)"%s/.tuxtype/settings.txt", getenv("HOME") );
-	#endif
+	//#ifdef WIN32
+    //    //MDTTEMP: Commented out the next line and added the next 2 lines after
+	//	//_mkdir( "userdata" );  // just in case try to create save location
+	//	snprintf( fn, FNLEN-1, (const char*)"%s/TuxType", getenv("APPDATA") );
+	//	_mkdir( fn );  // just in case try to create save location
+    //    // MDTTEMP: Commented out the next line and added the line after
+	//	//snprintf( fn, FNLEN-1, "userdata/settings.txt" );
+	//	snprintf( fn, FNLEN-1, "%s/TuxType/settings.txt", getenv("APPDATA"));
+	//#else
+	//	snprintf( fn, FNLEN-1, (const char*)"%s/.tuxtype", getenv("HOME") );
+	//	mkdir( fn, 0755 ); // just in case try to create save location
+	//	snprintf( fn, FNLEN-1, (const char*)"%s/.tuxtype/settings.txt", getenv("HOME") );
+	//#endif
+	
+	// Use the settings.user_settings_path member
+	snprintf( fn, FNLEN-1, (const char*)"%s/settings.txt", settings.user_settings_path );
 
 
 	DEBUGCODE { printf("SaveSettings: settings file is '%s'\n", fn ); }
@@ -349,8 +401,9 @@ void SaveSettings(void)
 	/* Save all the settings here! */
 //NOTE for now, don't save theme because things get screwed up if the language
 // doesn't match the LANG environmental variable - DSB
-//	if (strncmp(settings.theme_name, "", FNLEN) != 0)
-//		fprintf( settingsFile, "lang=%s\n", settings.theme_name );
+// MDTTEMP: uncommented the following 2 lines
+	if (strncmp(settings.theme_name, "", FNLEN) != 0)
+		fprintf( settingsFile, "lang=%s\n", settings.theme_name );
 	if (settings.o_lives > 9)
 		fprintf( settingsFile, "o_lives=%d\n", settings.o_lives );
 
@@ -378,7 +431,13 @@ void SaveSettings(void)
 
 int SetupPaths(const char* theme_dir)
 {
+  DEBUGCODE
+  {
+    fprintf(stderr, "Entering SetupPaths()\n");
+  }
+
   settings.use_english = 1; // default is to use English if we cannot find theme
+  char fn[FNLEN];           // used later when setting settings.user_settings_path
 
   if (CheckFile(DATA_PREFIX))
   {
@@ -419,7 +478,6 @@ int SetupPaths(const char* theme_dir)
       /* an explicit statement to use the default(                  */
       strncpy(settings.theme_font_name, DEFAULT_FONT_NAME, FNLEN);
       
-
       /* Load fontname or any other theme-specific settings: */
       sprintf(theme_settings_path, "%s/settings.txt", full_theme_path);
 
@@ -448,12 +506,6 @@ int SetupPaths(const char* theme_dir)
   }
 
 
-  DEBUGCODE
-  {
-    fprintf(stderr, "Leaving SetupPaths():\n");
-    fprintf(stderr, "default_data_path: '%s'\n", settings.default_data_path);
-    fprintf(stderr, "theme_data_path: '%s'\n\n", settings.theme_data_path);
-  }
 
   /* Now check for VAR_PREFIX (for modifiable data shared by all users, */ 
   /* such as custom word lists, high scores, etc:                       */
@@ -473,17 +525,72 @@ int SetupPaths(const char* theme_dir)
   /* Now check for CONF_PREFIX (for program wide settings that apply to all users). */ 
   /* This would typically be /etc/tuxtype if tuxtype is installed by a distro pkg,  */
   /* or /usr/local/etc/tuxtype if the package is built locally                      */
-  if (CheckFile(VAR_PREFIX))
+  if (CheckFile(CONF_PREFIX))
   {
-    strncpy(settings.var_data_path, VAR_PREFIX, FNLEN - 1);
-    DEBUGCODE {fprintf(stderr, "path '%s' found, copy to settings.var_data_path\n", VAR_PREFIX);}
+    strncpy(settings.global_settings_path, CONF_PREFIX, FNLEN - 1);
+    DEBUGCODE {fprintf(stderr, "path '%s' found, copy to settings.global_settings_path\n", CONF_PREFIX);}
   }
   else
   {
-    fprintf(stderr, "Error - VAR_PREFIX = '%s' not found!\n", VAR_PREFIX);
+    fprintf(stderr, "Error - CONF_PREFIX = '%s' not found!\n", CONF_PREFIX);
     return 0;
   }
 
+
+  /* Determine the user data path (for user specific settings)  this would normally be     */
+  /* /home/user/.tuxtype for POSIX systems or Documents and Settings/user/Application Data */
+  /* for windows systems                                                                   */
+  #ifdef WIN32
+    snprintf( fn, FNLEN-1, (const char*)"%s/TuxType", getenv("APPDATA") );
+  #else
+    snprintf( fn, FNLEN-1, (const char*)"%s/.tuxtype", getenv("HOME") );
+  #endif
+
+  if (CheckFile(fn))
+  {
+    strncpy(settings.user_settings_path, fn, FNLEN - 1);
+    DEBUGCODE {fprintf(stderr, "path '%s' found, copying to settings.user_settings_path\n", fn);}
+  }
+  else
+  {
+    fprintf(stderr, "Error - User Settings Path = '%s' not found, I will attempt to create it.\n", fn);
+  #ifdef WIN32
+     _mkdir( fn );
+  #else
+     mkdir( fn, 0755 );
+  #endif
+    if (CheckFile(fn))
+    {
+      strncpy(settings.user_settings_path, fn, FNLEN - 1);
+      DEBUGCODE {fprintf(stderr, "path '%s' successfully created, copy to settings.user_settings_path\n", fn);}
+    }
+    else
+    {
+      //NOTE this shouldn't happen, right? We should always be able to make a directory
+      //in our own home folder - DSB
+      fprintf(stderr, "Error - Could not create: '%s', falling back to the global settings.\n", fn);
+  #ifdef WIN32
+      strncpy(settings.user_settings_path, "userdata", FNLEN - 1);
+  #else
+      // FIXME: in this fallback case if we are forced to use global settings, and /etc/tuxtype
+      // contains those settings we can't write to it, so use /tmp - but then we have nothing to
+      // read from, copy the global settings to temp first?  Or just forget about saving the settings
+      // when we exit? - MDT
+      strncpy(settings.user_settings_path, "/tmp", FNLEN - 1);
+  #endif
+    }
+  }
+
+DEBUGCODE
+  {
+    fprintf(stderr, "Leaving SetupPaths():\n");
+    fprintf(stderr, "default_data_path: '%s'\n", settings.default_data_path);
+    fprintf(stderr, "theme_data_path: '%s'\n\n", settings.theme_data_path);
+    fprintf(stderr, "var_data_path: '%s'\n\n", settings.var_data_path);
+    fprintf(stderr, "user_settings_path: '%s'\n\n", settings.user_settings_path);
+    fprintf(stderr, "global_settings_path: '%s'\n\n", settings.global_settings_path);
+  }
+
   return 1;	
 }
 
