@@ -86,11 +86,11 @@ const char* menu_icon[][6] =
      
 static const char* menu_text[] = 
 {"", "",            "",             "",            ""    ,
- "",gettext_noop("Fish Cascade"),gettext_noop("Easy"),gettext_noop("Space Cadet"),gettext_noop("Edit Word Lists"),
- "",gettext_noop("Comet Zap"),gettext_noop("Medium"),gettext_noop("Pilot"),gettext_noop("Phrase Typing"),
- "",gettext_noop("Lessons"),gettext_noop("Hard"), gettext_noop("Ace"),gettext_noop("Project Info"),
- "", gettext_noop("Options"),gettext_noop("Instructions"),gettext_noop("Commander"),gettext_noop("Setup Language"),
- "", gettext_noop("Quit"),gettext_noop("Main Menu"),gettext_noop("Main Menu"),gettext_noop("Main Menu")};
+ "",N_("Fish Cascade"),N_("Easy"),N_("Space Cadet"),N_("Edit Word Lists"),
+ "",N_("Comet Zap"),N_("Medium"),N_("Pilot"),N_("Phrase Typing"),
+ "",N_("Lessons"),N_("Hard"), N_("Ace"),N_("Project Info"),
+ "", N_("Options"),N_("Instructions"),N_("Commander"),N_("Setup Language"),
+ "", N_("Quit"),N_("Main Menu"),N_("Main Menu"),N_("Main Menu")};
 
 
 
@@ -256,7 +256,7 @@ void TitleScreen(void)
   while (!done) 
   {
 
-    start=SDL_GetTicks();
+    start = SDL_GetTicks();
 
     /* ---process input queue --- */
 
@@ -269,11 +269,15 @@ void TitleScreen(void)
     {
       switch (event.type)
       {
-
+        /* Update "selection" if mouse moves within a menu entry: */
         case SDL_MOUSEMOTION:
         {
           cursor.x = event.motion.x;
           cursor.y = event.motion.y;
+
+	  for (j = 1; j <= TITLE_MENU_ITEMS; j++)
+            if (inRect(menu_button[j], cursor.x, cursor.y))
+              key_menu = j;
           break;
         }
 
@@ -387,6 +391,7 @@ void TitleScreen(void)
 
 
             case SDLK_UP:
+	    case SDLK_k:
             {
               if (settings.menu_sound)
                 PlaySound(snd_move);
@@ -398,6 +403,7 @@ void TitleScreen(void)
 
 
             case SDLK_DOWN:
+	    case SDLK_j:
             {
               key_menu++;
               if (settings.menu_sound)
@@ -752,8 +758,8 @@ void TitleScreen(void)
 
     /* --- check if mouse is in a menu option --- */
 
-    key_menu = 0;
-
+//    key_menu = 0;
+/*
     for (j = 1; j <= TITLE_MENU_ITEMS; j++)
     {
       if ((cursor.x >= menu_button[j].x && cursor.x <= (menu_button[j].x + menu_button[j].w)) &&
@@ -762,7 +768,7 @@ void TitleScreen(void)
         key_menu = j; // update menu to point
         break;        // Don't need to check rest of menu
       }
-    }
+    }*/
 
 
     /* --- return old selection to unselected state --- */
@@ -1110,9 +1116,9 @@ static void not_implemented(void)
 
   LOG( "NotImplemented() - creating text\n" );
 
-  s1 = BlackOutline( gettext_noop("Work In Progress!"), DEFAULT_MENU_FONT_SIZE, &white);
-  s2 = BlackOutline( gettext_noop("This feature is not ready yet"), DEFAULT_MENU_FONT_SIZE, &white);
-  s3 = BlackOutline( gettext_noop("Discuss the future of TuxTyping at"), DEFAULT_MENU_FONT_SIZE, &white);
+  s1 = BlackOutline( _("Work In Progress!"), DEFAULT_MENU_FONT_SIZE, &white);
+  s2 = BlackOutline( _("This feature is not ready yet"), DEFAULT_MENU_FONT_SIZE, &white);
+  s3 = BlackOutline( _("Discuss the future of TuxTyping at"), DEFAULT_MENU_FONT_SIZE, &white);
   s4 = BlackOutline( "http://tux4kids.alioth.debian.org/", DEFAULT_MENU_FONT_SIZE, &white);
 
   tux = LoadSprite("tux/tux-egypt", IMG_ALPHA);
@@ -1183,7 +1189,6 @@ static void not_implemented(void)
 
 
 
-#define MAX_WORD_LISTS 100
 
 /* returns 0 if user pressed escape ...
  *         1 if word list was set correctly
@@ -1213,37 +1218,38 @@ static int chooseWordlist(void)
 
   /* find the directory to load wordlists from */
 
-  /* Check under theme directory first, if theme selected: */
-  if (!settings.use_english)  /* Using theme: */
+  /* First we add the bundled word lists in either NLS or default theme: */
   {
-    sprintf(wordPath,"%s/words", settings.theme_data_path);
-    if (!CheckFile(wordPath))
+    if (!settings.use_english)  /* Using theme: */
     {
-      fprintf(stderr, "chooseWordList() - theme contains no wordlist dir \n");
-      return 0;
+      sprintf(wordPath,"%s/words", settings.theme_data_path);
+      if (!CheckFile(wordPath))
+      {
+        fprintf(stderr, "chooseWordList() - theme contains no wordlist dir \n");
+        return 0;
+      }
     }
-  }
-  else  /* No theme selected - using English: */
-  {
-    sprintf(wordPath,"%s/words", settings.default_data_path);
-    if (!CheckFile(wordPath))
+    else  /* No user settings or theme selected - using English: */
     {
-      fprintf(stderr, "chooseWordList() - data path contains no wordlist dir \n");
-      return 0;
+      sprintf(wordPath,"%s/words", settings.default_data_path);
+      if (!CheckFile(wordPath))
+      {
+        fprintf(stderr, "chooseWordList() - data path contains no wordlist dir \n");
+        return 0;
+      }
     }
   }
 
   /* If we get to here, we know there is at least a wordlist directory */
   /* but not necessarily any valid files.                              */
 
-  DEBUGCODE { fprintf(stderr, "wordPath is: %s\n", wordPath); }
+  DEBUGCODE { fprintf(stderr, "bundled wordPath is: %s\n", wordPath); }
 
 
   /* FIXME looks like a place for scandir() - or our own w32_scandir() */
+  /* FIXME we also have this block of code repeated three times - DSB  */
   /* create a list of all the .txt files */
-
   wordsDir = opendir( wordPath );	
-
   do
   {
     wordsFile = readdir(wordsDir);
@@ -1278,85 +1284,124 @@ static int chooseWordlist(void)
 
     fclose(tempFile);
   } while (1); /* Loop continues until break occurs */
-
   closedir(wordsDir);	
+
+  
+  
+  /* Adding global custom wordlists ------------------------------------ */
  
-
-/* Adding custom wordlists */
- 
-    sprintf(wordPath,"%s/words", settings.var_data_path);
-    if (!CheckFile(wordPath))
-    {
-      fprintf(stderr, "chooseWordList() - data path contains no wordlist dir \n");
-      return 0;
-    }
- 
-
-  /* If we get to here, we know there is at least a wordlist directory */
-  /* but not necessarily any valid files.                              */
-
-  DEBUGCODE { fprintf(stderr, "wordPath is: %s\n", wordPath); }
-
-
-  /* FIXME looks like a place for scandir() - or our own w32_scandir() */
-  /* create a list of all the .txt files */
-
-  wordsDir = opendir( wordPath );	
-
-  do
+  sprintf(wordPath,"%s/words", settings.var_data_path);
+  if (!CheckFile(wordPath))
   {
-    wordsFile = readdir(wordsDir);
-    if (!wordsFile)
-      break; /* Loop continues until break occurs */
+    DEBUGCODE { fprintf(stderr, "chooseWordList() -  path \"%s\" not found\n", wordPath); }
+  }
+  else
+  {
+    /* If we get to here, we know there is at least a wordlist directory */
+    /* but not necessarily any valid files.                              */
 
-    DEBUGCODE { fprintf(stderr, "wordsFile name is: %s\n", wordsFile->d_name); }
+    DEBUGCODE { fprintf(stderr, "global custom wordPath is: %s\n", wordPath); }
 
-    /* must have at least .txt at the end */
-    if (strlen(wordsFile->d_name) < 5)
-      continue;
+    /* FIXME looks like a place for scandir() - or our own w32_scandir() */
+    /* create a list of all the .txt files */
+    wordsDir = opendir( wordPath );	
+    do
+    {
+      wordsFile = readdir(wordsDir);
+      if (!wordsFile)
+        break; /* Loop continues until break occurs */
 
-    if (strcmp(&wordsFile->d_name[strlen(wordsFile->d_name) -4 ],".txt"))
-      continue;
+      DEBUGCODE { fprintf(stderr, "wordsFile name is: %s\n", wordsFile->d_name); }
 
-    sprintf(wordlistFile[lists], "%s/%s", wordPath, wordsFile->d_name);
+      /* must have at least .txt at the end */
+      if (strlen(wordsFile->d_name) < 5)
+        continue;
 
-    /* load the name for the wordlist from the file ... (1st line) */
-    tempFile = fopen( wordlistFile[lists], "r" );
-    if (!tempFile)
-      continue;
+      if (strcmp(&wordsFile->d_name[strlen(wordsFile->d_name) -4 ],".txt"))
+        continue;
 
-    result = fscanf(tempFile, "%[^\n]\n", wordlistName[lists]);
-    if (result == EOF)
-      continue;
+      sprintf(wordlistFile[lists], "%s/%s", wordPath, wordsFile->d_name);
 
-    /* check to see if it has a \r at the end of it (dos format!) */
-    if (wordlistName[lists][strlen(wordlistName[lists]) - 1] == '\r')
-      wordlistName[lists][strlen(wordlistName[lists]) - 1] = '\0';
+      /* load the name for the wordlist from the file ... (1st line) */
+      tempFile = fopen( wordlistFile[lists], "r" );
+      if (!tempFile)
+        continue;
 
-    lists++;
+      result = fscanf(tempFile, "%[^\n]\n", wordlistName[lists]);
+      if (result == EOF)
+        continue;
 
-    fclose(tempFile);
-  } while (1); /* Loop continues until break occurs */
+      /* check to see if it has a \r at the end of it (dos format!) */
+      if (wordlistName[lists][strlen(wordlistName[lists]) - 1] == '\r')
+        wordlistName[lists][strlen(wordlistName[lists]) - 1] = '\0';
 
-  closedir(wordsDir);
+      lists++;
 
+      fclose(tempFile);
+    } while (1); /* Loop continues until break occurs */
+    closedir(wordsDir);
+  }
+  
+  /* Now add any lists in the user's personal settings path: ------------ */
 
+  sprintf(wordPath,"%s/words", settings.user_settings_path);
+  if (!CheckFile(wordPath))
+  {
+    DEBUGCODE { fprintf(stderr, "chooseWordList() -  path \"%s\" not found\n", wordPath); }
+  }
+  else
+  {
+    /* If we get to here, we know there is at least a wordlist directory */
+    /* but not necessarily any valid files.                              */
 
+    DEBUGCODE { fprintf(stderr, "user-specific wordPath is: %s\n", wordPath); }
 
- DEBUGCODE { fprintf(stderr, "Found %d .txt file(s) in words dir\n", lists); }
+    /* FIXME looks like a place for scandir() - or our own w32_scandir() */
+    /* create a list of all the .txt files */
+    wordsDir = opendir( wordPath );	
+    do
+    {
+      wordsFile = readdir(wordsDir);
+      if (!wordsFile)
+        break; /* Loop continues until break occurs */
 
+      DEBUGCODE { fprintf(stderr, "wordsFile name is: %s\n", wordsFile->d_name); }
 
+      /* must have at least .txt at the end */
+      if (strlen(wordsFile->d_name) < 5)
+        continue;
 
-  /* let the user pick the list */
+      if (strcmp(&wordsFile->d_name[strlen(wordsFile->d_name) -4 ],".txt"))
+        continue;
+
+      sprintf(wordlistFile[lists], "%s/%s", wordPath, wordsFile->d_name);
+
+      /* load the name for the wordlist from the file ... (1st line) */
+      tempFile = fopen( wordlistFile[lists], "r" );
+      if (!tempFile)
+        continue;
+
+      result = fscanf(tempFile, "%[^\n]\n", wordlistName[lists]);
+      if (result == EOF)
+        continue;
+
+      /* check to see if it has a \r at the end of it (dos format!) */
+      if (wordlistName[lists][strlen(wordlistName[lists]) - 1] == '\r')
+        wordlistName[lists][strlen(wordlistName[lists]) - 1] = '\0';
+
+      lists++;
+
+      fclose(tempFile);
+    } while (1); /* Loop continues until break occurs */
+    closedir(wordsDir);
+  }
+
+  DEBUGCODE { fprintf(stderr, "Found %d .txt file(s) in words dir\n", lists); }
+
+  
+  /* Done scanning for word lists, now display them for user selection: */
 
   /* Render SDL_Surfaces for list entries: */
-//  titles[0] = BlackOutline( _("Alphabet"), font, &white );
-//  select[0] = BlackOutline( _("Alphabet"), font, &yellow);
-
-  /* NOTE - no longer hard-coding titles[0] to be alphabet - themes  */
-  /* should include a regular word list file called "alphabet.txt"   */
-  /* Should sort the list and always put the alphabet file first, if */
-  /* present.                                                        */
   for (i = 0; i < lists; i++)
   {
     titles[i] = BlackOutline( wordlistName[i], DEFAULT_MENU_FONT_SIZE, &white );
@@ -1488,13 +1533,17 @@ static int chooseWordlist(void)
               loc = (loc - (loc % 8) + 8);
           }
 
-          if (event.key.keysym.sym == SDLK_UP)
+          if ((event.key.keysym.sym == SDLK_UP)
+	     ||
+	      (event.key.keysym.sym == SDLK_k))
           {
             if (loc > 0)
               loc--;
           }
 
-          if (event.key.keysym.sym == SDLK_DOWN)
+          if ((event.key.keysym.sym == SDLK_DOWN)
+	     ||
+	      (event.key.keysym.sym == SDLK_j))
           {
             if (loc+1<lists)
               loc++;
